#!/bin/bash
# License GPL
# By Cimi & Tome & TheLeashedHare

function check_root {
	ROOT_UID=0
	E_NONROOT=67
	if [ "$UID" -ne "$ROOT_UID" ]
	then
		echo "This script requires root permissions.
Please login as root or launch \"sudo ./install.sh\""
		exit $E_NONROOT
	fi
}

function usage {
	echo "Usage: ./install.sh [OPTION]"
	echo "Install New Murrine Configurator.
It automatically detect previous installations and upgrade them."
	echo ""
	echo "Options:"
	echo "--prefix <path-to-install>
  Select the path where install the program. Default: /usr."
	echo "--uninstall
  Uninstall Murrine Configurator."
	echo "--help
  Print this help screen."
}

function check_install {
	if [ -z "$1" ]; then
		echo "No prefix given, assuming installation in /usr.."
	  PREFIX="/usr"
	else
	  PREFIX=$1
		echo "Files will be installed under ${PREFIX}..."
	fi
	sleep 1
	if [ ! -d ${PREFIX}/bin ]
	then
		echo "Error: ${PREFIX}/bin doesn't exist."
		exit 1
	fi
}

function installation {
	echo "Installing files under $PREFIX..."
	sleep 1
	install -m0644 src/murrine-configurator.png ${PREFIX}/share/pixmaps
	install -m0644 src/murrine-configurator.desktop ${PREFIX}/share/applications
	mkdir ${PREFIX}/share/nmc
	install -m0644 src/*.glade ${PREFIX}/share/nmc
	install -m0644 src/*.py* ${PREFIX}/share/nmc
	install -m0755 src/newmurrineconfigurator.py ${PREFIX}/share/nmc

	if [ ! -e previous_installation.log ]
	then 
		echo "$PREFIX" > previous_installation.log
		echo "New Murrine Configurator successefully installed."
	else
			echo ""
			echo "Detected precedent installation! Running uninstall"
			sleep 1
			uninstall
			echo ""
			installation
	fi
}

function uninstall {
	if [ ! -e previous_installation.log ]
	then
		echo "New Murrine Configurator seems not to be installed.
Anyway uninstall process will continue..."
	sleep 2
	else
		UNINSTALL_PREFIX=`cat previous_installation.log`
	fi
	echo "Running uninstall..."
	sleep 1
	rm -rf ${UNINSTALL_PREFIX}/share/pixmaps/murrine-configurator.png
	rm -rf ${UNINSTALL_PREFIX}/share/applications/murrine-configurator.desktop
	rm -rf ${UNINSTALL_PREFIX}/share/nmc
	rm -rf previous_installation.log
	echo "New Murrine Configurator successefully uninstalled."
	sleep 1
}

### Startup ###
check_root
if [ "$1" = "-h" -o "$1" = "--help" ]; then
	usage
	exit 0
elif [ "$1" = "--prefix" ]; then
	PREFIX=$2
elif [ "$1" = "--uninstall" ]; then
	uninstall
	exit 0
fi
check_install $PREFIX
installation
